==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/bn_BD.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "সংরক্ষণের স্থান নেই",
    "Storage invalid" : "সংরক্ষণাগার বৈধ নয়",
    "Unknown error" : "অজানা জটিলতা",
    "Could not move %s - File with this name already exists" : "%s কে স্থানান্তর করা সম্ভব হলো না -  এই নামের ফাইল বিদ্যমান",
    "Could not move %s" : "%s  কে স্থানান্তর করা সম্ভব হলো না",
    "Permission denied" : "অনুমতি দেয়া হয়নি",
    "Error when creating the file" : "ফাইলটি তৈরী করতে যেয়ে সমস্যা হলো",
    "Error when creating the folder" : "ফোল্ডার তৈরী করতে যেয়ে সমস্যা হলো",
    "Unable to set upload directory." : "েআপলোড ডিরেক্টরি নির্ধারণ করা গেলনা।",
    "No file was uploaded. Unknown error" : "কোন ফাইল আপলোড করা হয় নি। সমস্যার কারণটি অজ্ঞাত।",
    "There is no error, the file uploaded with success" : "কোন সমস্যা হয় নি, ফাইল আপলোড সুসম্পন্ন হয়েছে।",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "আপলোড করা  ফাইলটি php.ini তে বর্ণিত  upload_max_filesize নির্দেশিত আয়তন অতিক্রম করছেঃ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "আপলোড করা ফাইলটি  HTML  ফর্মে উল্লিখিত MAX_FILE_SIZE নির্ধারিত ফাইলের সর্বোচ্চ আকার  অতিক্রম করতে চলেছে ",
    "The uploaded file was only partially uploaded" : "আপলোড করা ফাইলটি আংশিক আপলোড করা হয়েছে",
    "No file was uploaded" : "কোন ফাইল আপলোড করা হয় নি",
    "Missing a temporary folder" : "অস্থায়ী ফোল্ডারটি হারানো গিয়েছে",
    "Failed to write to disk" : "ডিস্কে লিখতে ব্যর্থ",
    "Not enough storage available" : "সংরক্ষণের যথেষ্ট জায়গা প্রাপ্তব্য নয়",
    "Invalid directory." : "ভুল ডিরেক্টরি",
    "Files" : "ফাইল",
    "All files" : "সব ফাইল",
    "Favorites" : "প্রিয়জন",
    "Home" : "নিবাস",
    "Upload cancelled." : "আপলোড বাতিল করা হয়েছে।",
    "File upload is in progress. Leaving the page now will cancel the upload." : "ফাইল আপলোড চলমান। এই পৃষ্ঠা পরিত্যাগ করলে আপলোড বাতিল করা হবে।",
    "{new_name} already exists" : "{new_name} টি বিদ্যমান",
    "Rename" : "পূনঃনামকরণ",
    "Delete" : "মুছে",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "Download" : "ডাউনলোড",
    "Pending" : "মুলতুবি",
    "Error moving file." : "ফাইল সরাতে সমস্যা হলো।",
    "Error moving file" : "ফাইল সরাতে সমস্যা হলো",
    "Error" : "সমস্যা",
    "Could not rename file" : "ফাইলের পূণঃনামকরণ করা গেলনা",
    "Name" : "রাম",
    "Size" : "আকার",
    "Modified" : "পরিবর্তিত",
    "_Uploading %n file_::_Uploading %n files_" : ["%n ফাইল আপলোড হচ্ছে","%n ফাইল আপলোড হচ্ছে"],
    "\"{name}\" is an invalid file name." : "\"{name}\" টি একটি অননুমোদিত ফাইল নাম।",
    "File name cannot be empty." : "ফাইলের নামটি ফাঁকা রাখা যাবে না।",
    "Your storage is almost full ({usedSpacePercent}%)" : "আপনার সংরক্ষণাধার প্রায় পরিপূর্ণ ({usedSpacePercent}%) ",
    "Favorite" : "প্রিয়জন",
    "A new file or folder has been <strong>created</strong>" : "একটি ফাইল বা ফোলডার <strong>তৈরি</strong> করা হয়েছে",
    "A file or folder has been <strong>changed</strong>" : "একটি ফাইল বা ফোলডার <strong>পরিবরতন</strong> করা হয়েছে",
    "A file or folder has been <strong>deleted</strong>" : "একটি ফাইল বা ফোলডার <strong>মোছা</strong> হয়েছে",
    "You created %1$s" : "আপনি তৈরি করেছেন %1$s",
    "%2$s created %1$s" : "%2$s তৈরি হয়েছে %1$s",
    "%1$s was created in a public folder" : "একটি পাবলিক ফোল্ডারে %1$s তৈরী করা হয়েছে",
    "You changed %1$s" : "আপনি পরিবরতন করেছেন %1$s",
    "%2$s changed %1$s" : "%2$s পরিবরতন করেছে %1$s",
    "You deleted %1$s" : "আপনি ডিলিট করেছেন %1$s",
    "%2$s deleted %1$s" : "%2$s ডিলিট করেছে %1$s",
    "File handling" : "ফাইল হ্যার্ডলিং",
    "Maximum upload size" : "আপলোডের সর্বোচ্চ আকার",
    "max. possible: " : "অনুমোদিত  সর্বোচ্চ  আকার",
    "Save" : "সংরক্ষণ",
    "Settings" : "নিয়ামকসমূহ",
    "WebDAV" : "WebDAV",
    "New" : "নতুন",
    "Text file" : "টেক্সট ফাইল",
    "New folder" : "নব ফােলডার",
    "Folder" : "ফোল্ডার",
    "Upload" : "আপলোড",
    "Cancel upload" : "আপলোড বাতিল কর",
    "Upload too large" : "আপলোডের আকারটি অনেক বড়",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "আপনি এই সার্ভারে আপলোড করার জন্য অনুমোদিত ফাইলের সর্বোচ্চ আকারের চেয়ে বৃহদাকার ফাইল আপলোড করার চেষ্টা করছেন ",
    "Files are being scanned, please wait." : "ফাইলগুলো স্ক্যান করা হচ্ছে, দয়া করে অপেক্ষা করুন।"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/bn_BD.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "সংরক্ষণাগার বৈধ নয়",
    "Unknown error" : "অজানা জটিলতা",
    "All files" : "সব ফাইল",
    "Saved" : "সংরক্ষণ করা হলো",
    "Home" : "নিবাস",
    "Close" : "বন্ধ",
    "Favorites" : "প্রিয়জন",
    "Upload cancelled." : "আপলোড বাতিল করা হয়েছে।",
    "Uploading..." : "আপলোড করা হচ্ছে..........",
    "File upload is in progress. Leaving the page now will cancel the upload." : "ফাইল আপলোড চলমান। এই পৃষ্ঠা পরিত্যাগ করলে আপলোড বাতিল করা হবে।",
    "Actions" : "পদক্ষেপসমূহ",
    "Download" : "ডাউনলোড",
    "Rename" : "পূনঃনামকরণ",
    "Delete" : "মুছে",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "Files" : "ফাইল",
    "Details" : "বিস্তারিত",
    "Pending" : "মুলতুবি",
    "Invalid path" : "পথটি সঠিক নয়",
    "Name" : "রাম",
    "Size" : "আকার",
    "Modified" : "পরিবর্তিত",
    "_Uploading %n file_::_Uploading %n files_" : ["%n ফাইল আপলোড হচ্ছে","%n ফাইল আপলোড হচ্ছে"],
    "New" : "নতুন",
    "\"{name}\" is an invalid file name." : "\"{name}\" টি একটি অননুমোদিত ফাইল নাম।",
    "File name cannot be empty." : "ফাইলের নামটি ফাঁকা রাখা যাবে না।",
    "Your storage is almost full ({usedSpacePercent}%)" : "আপনার সংরক্ষণাধার প্রায় পরিপূর্ণ ({usedSpacePercent}%) ",
    "Favorite" : "প্রিয়জন",
    "Folder" : "ফোল্ডার",
    "New folder" : "নব ফােলডার",
    "Upload" : "আপলোড",
    "A new file or folder has been <strong>created</strong>" : "একটি ফাইল বা ফোলডার <strong>তৈরি</strong> করা হয়েছে",
    "A file or folder has been <strong>changed</strong>" : "একটি ফাইল বা ফোলডার <strong>পরিবরতন</strong> করা হয়েছে",
    "A file or folder has been <strong>deleted</strong>" : "একটি ফাইল বা ফোলডার <strong>মোছা</strong> হয়েছে",
    "You created %1$s" : "আপনি তৈরি করেছেন %1$s",
    "%2$s created %1$s" : "%2$s তৈরি হয়েছে %1$s",
    "%1$s was created in a public folder" : "একটি পাবলিক ফোল্ডারে %1$s তৈরী করা হয়েছে",
    "You changed %1$s" : "আপনি পরিবরতন করেছেন %1$s",
    "%2$s changed %1$s" : "%2$s পরিবরতন করেছে %1$s",
    "You deleted %1$s" : "আপনি ডিলিট করেছেন %1$s",
    "%2$s deleted %1$s" : "%2$s ডিলিট করেছে %1$s",
    "File handling" : "ফাইল হ্যার্ডলিং",
    "Maximum upload size" : "আপলোডের সর্বোচ্চ আকার",
    "max. possible: " : "অনুমোদিত  সর্বোচ্চ  আকার",
    "Save" : "সংরক্ষণ",
    "Settings" : "নিয়ামকসমূহ",
    "WebDAV" : "WebDAV",
    "Upload too large" : "আপলোডের আকারটি অনেক বড়",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "আপনি এই সার্ভারে আপলোড করার জন্য অনুমোদিত ফাইলের সর্বোচ্চ আকারের চেয়ে বৃহদাকার ফাইল আপলোড করার চেষ্টা করছেন ",
    "Text file" : "টেক্সট ফাইল"
},
"nplurals=2; plural=(n != 1);");
